==> mfgtools_1.5.141.orig.tar.gz: mfgtools-uuu_1.5.141/libuuu/sparse.h <==
/*
* Copyright 2018 NXP.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this
* list of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or
* other materials provided with the distribution.
*
* Neither the name of the NXP Semiconductor nor the names of its
* contributors may be used to endorse or promote products derived from this
* software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*
*/
#pragma once

#include "sparse_format.h"

#include <cstddef>
#include <vector>

class SparseFile
{
public:
	std::vector<uint8_t> m_data;

	static chunk_header_t * get_next_chunk(uint8_t *p, size_t &pos);

	int init_header(size_t blsz, int blcount);

	bool is_append_old_chuck(int type, void *p);
	bool is_same_value(void *data, size_t sz);
	static bool is_validate_sparse_file(void *p, size_t sz);

	int push(void *p, size_t sz);
	int push_one_block(void *data);
	size_t push_one_chuck(chunk_header_t *p, void *data);
	size_t push_raw_data(void *data, size_t sz);

private:
	size_t m_cur_chunk_header_pos;
	size_t m_max_size;
	uint32_t *m_pcrc;
};

==> mfgtools_1.5.239.orig.tar.gz: mfgtools-uuu_1.5.239/libuuu/sparse.h <==
/*
* Copyright 2018 NXP.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*
* Redistributions of source code must retain the above copyright notice, this
* list of conditions and the following disclaimer.
*
* Redistributions in binary form must reproduce the above copyright notice, this
* list of conditions and the following disclaimer in the documentation and/or
* other materials provided with the distribution.
*
* Neither the name of the NXP Semiconductor nor the names of its
* contributors may be used to endorse or promote products derived from this
* software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*
*/
#pragma once

#include "sparse_format.h"

#include <cstddef>
#include <vector>

class SparseFile
{
public:
	std::vector<uint8_t> m_data;

	static chunk_header_t * get_next_chunk(uint8_t *p, size_t &pos);

	int init_header(size_t blsz, int blcount);

	bool is_append_old_chuck(int type, void *p);
	bool is_same_value(void *data, size_t sz);
	static bool is_validate_sparse_file(void *p, size_t sz);

	int push(void *p, size_t sz);
	int push_one_block(void *data, bool skip=false);
	size_t push_one_chuck(chunk_header_t *p, void *data);
	size_t push_raw_data(void *data, size_t sz);

private:
	size_t m_cur_chunk_header_pos;
	size_t m_max_size;
	uint32_t *m_pcrc;
};
